<?php

class eStore_country_blocking_Settings_Page {
    /*
     * Declare keys here as well as our tabs array which 
     * is populated when registering settings
     */

    var $plugin_settings_page_key = 'estore_country_blocking_settings_page';
    var $plugin_options_key = 'estore_country_blocking_options';
    var $plugin_settings_tabs = array();

    function __construct() {
        add_action('init', array(&$this, 'load_settings'));
        add_action('admin_init', array(&$this, 'register_plugin_settings_page'));
        add_action('admin_menu', array(&$this, 'add_admin_menus'));
    }

    /*
     * Loads both tab settings from
     * the database into their respective arrays. Uses
     * array_merge to merge with default values if they're
     * missing.
     */

    function load_settings() {
        $this->plugin_settings = (array) get_option($this->plugin_settings_page_key);

// Merge with defaults
        $this->plugin_settings = array_merge(array(
            'estore_country_blocking_option' => 'estore country blocking settings'
                ), $this->plugin_settings);
    }

    /*
     * Registers the display templates page via the Settings API,
     * appends the setting to the tabs array of the object.
     */

    function register_plugin_settings_page() {
        $this->plugin_settings_tabs[$this->plugin_settings_page_key] = 'Country Blocking';
        register_setting($this->plugin_settings_page_key, $this->plugin_settings_page_key);
    }

    /*     * ****************************************************************************
     * Now we just need to define an admin page.
     * **************************************************************************** */

    /*
     * Called during admin_menu, adds an options
     * page under Settings 
     */

    function add_admin_menus() {
        if ( !defined('WP_ESTORE_PATH') ){
            //The core estore plugin is not active. Bail out.
            return;
        }
        $parent_slug = WP_ESTORE_PATH . "wp_eStore1.php";
        $page_title = "Country Blocking";
        $menu_title = "Country Blocking";
        add_submenu_page($parent_slug, $page_title, $menu_title, ESTORE_MANAGEMENT_PERMISSION, $this->plugin_options_key, array(&$this, 'estore_custom_addon_settings_page'));
    }

    /*
     * Plugin Options page rendering goes here, checks
     * for active tab and replaces key with the related
     * settings key. Uses the plugin_options_tabs method
     * to render the tabs.
     */

    function estore_custom_addon_settings_page() {
        $tab = isset($_GET['tab']) ? $_GET['tab'] : $this->plugin_settings_page_key;
        ?>
        <div class="wrap">
            <div id="poststuff"><div id="post-body">
                    <?php
                    $this->plugin_options_tabs();
                    if ($tab == $this->plugin_settings_page_key) {
                        $this->estore_custom_addon_general_settings_menu();
                    }
                    ?>
                </div></div>			
        </div>
        <?php
    }

    function current_tab() {
        $tab = isset($_GET['tab']) ? $_GET['tab'] : $this->plugin_settings_page_key;
        return $tab;
    }

    /*
     * Renders our tabs in the plugin options page,
     * walks through the object's tabs array and prints
     * them one by one. Provides the heading for the
     * plugin_options_page method.
     */

    function plugin_options_tabs() {
        $current_tab = isset($_GET['tab']) ? $_GET['tab'] : $this->plugin_settings_page_key;

        echo '<h2 class="nav-tab-wrapper">';
        foreach ($this->plugin_settings_tabs as $tab_key => $tab_caption) {
            $active = $current_tab == $tab_key ? 'nav-tab-active' : '';
            echo '<a class="nav-tab ' . $active . '" href="?page=' . $this->plugin_options_key . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';
        }
        echo '</h2>';
    }

    function estore_custom_addon_general_settings_menu() {
        if (isset($_POST['eStore_country_blocking_save'])) {
            $nonce = $_REQUEST['_wpnonce'];
            if (!wp_verify_nonce($nonce, 'eStore_country_blocking_save')) {
                wp_die('Error! Nonce Security Check Failed! Go back to settings menu and save the settings again.');
            }
            $country_block_fields_obj = eStore_country_block_fields::get_instance();
            $country_block_fields_obj->block_msg = trim(stripcslashes($_POST["eStore_country_block_msg"]));
            if(empty($country_block_fields_obj->block_msg)){
                $country_block_fields_obj->block_msg = "Sorry! we do not sell to your country";
            }
            $country_block_fields_obj->block_msg_digi_goods = trim(stripcslashes($_POST["eStore_country_block_msg_digi_goods"]));
            if(empty($country_block_fields_obj->block_msg_digi_goods)){
                $country_block_fields_obj->block_msg_digi_goods = "Sorry! we do not sell digital goods to your country";
            }
            $country_block_fields_obj->block_digital_goods = (isset($_POST['eStore_country_block_digi_goods'])) ? 1 : 0;
            $country_block_fields_obj->countries = array();
            if(isset($_POST['selected_countries']) && is_array($_POST['selected_countries']))
            {
                $count = 1;
                foreach ($_POST['selected_countries'] as $code => $name) {
                    $country = new eStore_country_block_element();
                    $country->id = $count;
                    $country->country_code = $code;
                    $country->country_name = $name;
                    $country_block_fields_obj->add_country($country);
                    $count = $count + 1;
                }
            }
            eStore_country_block_fields::save_object($country_block_fields_obj);
            echo '<div id="message" class="updated fade"><p><strong>';
            echo 'Options Saved!';
            echo '</strong></p></div>';
        }

        //reset all form fields
        if (isset($_REQUEST['action']) && $_REQUEST['action'] == 'reset') {
            $country_block_fields_obj = new eStore_country_block_fields();
            $country_block_fields_obj = estore_country_blocking_default_options($country_block_fields_obj);
            eStore_country_block_fields::save_object($country_block_fields_obj);
            echo '<div id="message" class="updated fade"><p>';
            echo 'Options successfully reset!';
            echo '</p></div>';
        }
        ?>

        <div style="background: none repeat scroll 0 0 #FFF6D5;border: 1px solid #D1B655;color: #3F2502;margin: 10px 0;padding: 5px 5px 5px 10px;text-shadow: 1px 1px #FFFFFF;">	
            <p>For more information, updates, detailed documentation and video tutorial, please visit:<br />
                <a href="https://www.tipsandtricks-hq.com/ecommerce/?p=3492" target="_blank">Country Blocking Addon Homepage</a></p>
        </div>

        <div class="postbox">
            <div class="inside">

                <?php $country_block_fields_obj = eStore_country_block_fields::get_instance(); ?>
                <form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
                    <?php wp_nonce_field('eStore_country_blocking_save'); ?>
                    <table class="form-table" border="0" cellspacing="0" cellpadding="6" style="max-width:650px;"> 

                        <tr valign="top">
                            <th scope="row"><label for="eStore_country_block_msg">Error Message</label></th>
                            <td><input name="eStore_country_block_msg" type="text" id="eStore_country_block_msg" size="10" value="<?php echo $country_block_fields_obj->block_msg; ?>" class="regular-text">
                                <p class="description">Default error message for blocked users</p></td>
                        </tr>
                        
                        <tr valign="top">
                            <th scope="row"><label for="eStore_country_block_msg_digi_goods">Error Message for Digital Goods</label></th>
                            <td><input name="eStore_country_block_msg_digi_goods" type="text" id="eStore_country_block_msg_digi_goods" size="10" value="<?php echo $country_block_fields_obj->block_msg_digi_goods; ?>" class="regular-text">
                                <p class="description">Error message if there are digital goods in the shopping cart</p></td>
                        </tr>
                        
                        <tr valign="top">
                            <th scope="row">Block Digital Goods</th>
                            <td>
                            <label><input type="checkbox" name="eStore_country_block_digi_goods" value="1" <?php if ($country_block_fields_obj->block_digital_goods==1) echo ' checked="checked"'; ?>>If checked selected countries will be blocked only from being able to purchase digital goods (by default they are blocked regardless of the product types)</label><br>
                            </td>    
                        </tr>
                        
                        <tr valign="top">
                            <th scope="row">Select Countries</th>
                            <td>
                            <?php
                            $countries = ESTORE_COUNTRY_BLOCKING::get_country_list();
                            foreach ($countries as $code => $name) {
                            ?>
                            <label><input type="checkbox" name="selected_countries[<?php echo $code; ?>]" value="<?php echo $name;?>" <?php if ($country_block_fields_obj->is_country_blocked($code)) echo ' checked="checked"'; ?>> <?php echo $name; ?></label><br>
                            <?php } ?>
                            </td>    
                        </tr>

                        <tr>
                            <td width="25%" align="left">
                                <div class="submit">
                                    <input type="submit" name="eStore_country_blocking_save" class="button-primary" value="Save &raquo;" />
                                </div>                
                            </td>
                        </tr>

                    </table>

                </form>    

            </div></div>

        <?php
        $output = '';
        $output .= '<p>';
        $output .= '<a href="admin.php?page=estore_country_blocking_options&action=reset" style="margin-left:10px;">Reset to Default</a>';
        $output .= '</p>';
        echo $output;
    }

}

//end class